# flashinfer_bench.data.Definition

```{eval-rst}
.. currentmodule:: flashinfer_bench.data

.. autopydantic_model:: Definition

.. autopydantic_model:: AxisConst

.. autopydantic_model:: AxisVar

.. autopydantic_model:: TensorSpec

.. autoclass:: flashinfer_bench.data.definition.DType
    :members:
```
